@@ -28,7 +28,9 @@ impl<'a> Default for OSConfig<'a> {
             format: "[$symbol]($style)",
             style: "bold white",
             symbols: indexmap! {
+                Type::AIX => "➿ ",
                 Type::Alpaquita => "🔔 ",
+                Type::AlmaLinux => "💠 ",
                 Type::Alpine => "🏔️ ",
                 Type::Amazon => "🙂 ",
                 Type::Android => "🤖 ",
@@ -45,6 +47,7 @@ impl<'a> Default for OSConfig<'a> {
                 Type::Gentoo => "🗜️ ",
                 Type::HardenedBSD => "🛡️ ",
                 Type::Illumos => "🐦 ",
+                Type::Kali => "🐉 ",
                 Type::Linux => "🐧 ",
                 Type::Mabox => "📦 ",
                 Type::Macos => "🍎 ",
@@ -63,11 +66,14 @@ impl<'a> Default for OSConfig<'a> {
                 Type::Raspbian => "🍓 ",
                 Type::Redhat => "🎩 ",
                 Type::RedHatEnterprise => "🎩 ",
+                Type::RockyLinux => "💠 ",
                 Type::Redox => "🧪 ",
                 Type::Solus => "⛵ ",
                 Type::SUSE => "🦎 ",
                 Type::Ubuntu => "🎯 ",
+                Type::Ultramarine => "🔷 ",
                 Type::Unknown => "❓ ",
+                Type::Void => "  ",
                 Type::Windows => "🪟 ",
                 // Future symbols.
                 //aosc =>       " ",
@@ -79,7 +85,6 @@ impl<'a> Default for OSConfig<'a> {
                 //mandriva =>   " ",
                 //sabayon =>    " ",
                 //slackware =>  " ",
-                //void =>       " ",
                 //solaris =>    " ",
             },
             disabled: true,
