@@ -27,6 +27,7 @@ pub const ALL_MODULES: &[&str] = &[
     "dart",
     "deno",
     "directory",
+    "direnv",
     "docker_context",
     "dotnet",
     "elixir",
@@ -35,6 +36,7 @@ pub const ALL_MODULES: &[&str] = &[
     "fennel",
     "fill",
     "fossil_branch",
+    "fossil_metrics",
     "gcloud",
     "git_branch",
     "git_commit",
@@ -73,6 +75,7 @@ pub const ALL_MODULES: &[&str] = &[
     "pulumi",
     "purescript",
     "python",
+    "quarto",
     "raku",
     "red",
     "rlang",
@@ -89,6 +92,7 @@ pub const ALL_MODULES: &[&str] = &[
     "swift",
     "terraform",
     "time",
+    "typst",
     "username",
     "vagrant",
     "vcsh",
@@ -231,7 +235,7 @@ where
                 strs.into_iter()
                     .chain(std::iter::once(fill.ansi_string(fill_size)))
             })
-            .chain(current.into_iter())
+            .chain(current)
             .collect::<Vec<AnsiString>>()
     }
 }
